==> haskell-hls-overloaded-record-dot-plugin-2.1.0.0-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-overloaded-record-dot-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-overloaded-record-dot-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-overloaded-record-dot-plugin-2.1.0.0-AzDJGhdMXysGEY2KaYgwqU

key:
    hls-overloaded-record-dot-plugin-2.1.0.0-AzDJGhdMXysGEY2KaYgwqU

license:              BSD-3-Clause
maintainer:           joyfulmantis@gmail.com
author:               Nathan Maxson
synopsis:             Overloaded record dot plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8220c57a3580cabd28429341a48602e2
exposed:              True
exposed-modules:      Ide.Plugin.OverloadedRecordDot
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-overloaded-record-dot-plugin
hs-libraries:
    HShls-overloaded-record-dot-plugin-2.1.0.0-AzDJGhdMXysGEY2KaYgwqU

depends:
    aeson-2.1.2.1-LTS2NYlb1uX1OFFp0jy4wh base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-EYMTVOyZMMaC6uF1m4eXhb
    hls-graph-2.1.0.0-CIT2AImOP8m12ug7Dw0wAV
    hls-plugin-api-2.1.0.0-e6GrNFwzFvKJpzjvkMU36
    lens-5.3.1-Hr3CNVd7aJGEq0oCRlwS0q
    lsp-2.1.0.0-ESPZwykhtv3A4GR6I6px0n syb-0.7.3-LPfhh2IkSTRDzLRUGx5SDy
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-AhSAKQoMQ97FOa03PWrXZ

haddock-interfaces:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html/hls-overloaded-record-dot-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-overloaded-record-dot-plugin-2.1.0.0-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-overloaded-record-dot-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-overloaded-record-dot-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-overloaded-record-dot-plugin-2.1.0.0-43u2qV5WiAxL6dsN8wIVuo

key:
    hls-overloaded-record-dot-plugin-2.1.0.0-43u2qV5WiAxL6dsN8wIVuo

license:              BSD-3-Clause
maintainer:           joyfulmantis@gmail.com
author:               Nathan Maxson
synopsis:             Overloaded record dot plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e994f0128413e0ee8ff4c895adaca920
exposed:              True
exposed-modules:      Ide.Plugin.OverloadedRecordDot
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-overloaded-record-dot-plugin
hs-libraries:
    HShls-overloaded-record-dot-plugin-2.1.0.0-43u2qV5WiAxL6dsN8wIVuo

depends:
    aeson-2.1.2.1-AuEsVg6Hhe2CPhaLp40FYe base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-IfdVyiF6AwPDHn2TbAPnXk
    hls-graph-2.1.0.0-CKpYjZtV40aGyPfbCsIcyO
    hls-plugin-api-2.1.0.0-2tKKyoZfjr7D6pGZz9pYOL
    lens-5.3.1-DW98VpYgL8e3Qofq450fQJ
    lsp-2.1.0.0-6qUz56YkN9c2lHkJ0EY2b5 syb-0.7.3-GzxvBIT7N6LHXGQxqlBVFk
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-FOY8P5Y3sqjANbVUEJi9Vi

haddock-interfaces:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html/hls-overloaded-record-dot-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
